@@ -1,6 +1,7 @@
 """
 Guess by extension
 """
+import os
 from typing import List
 
 from whats_that_code.known_languages import FILE_EXTENSIONS
@@ -12,17 +13,22 @@ def guess_by_extension(file_name: str = "", text: str = "") -> List[str]:
     """
     if not file_name and not text:
         return []
+    _, extension_part = os.path.splitext(file_name)
+
+    if not extension_part:
+        return []
 
     guesses = set()
     extensions = []
     if file_name:
-        extensions.append("." + file_name.split(".")[1])
+        # TODO: use
+        extensions.append(extension_part)
     if text:
         words = [_ for _ in text.split(" ") if "." in _]
         for word in words:
             if word.endswith("."):
                 continue
-            extension = word.split(".")[1]
+            _, extension = os.path.splitext(word)
             if 1 < len(extension) < 5:
                 extensions.append(extension)
 
